var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
const {resolve} = require('path')

var indexRouter = require('./routes/index');
var paymentRouter = require('./routes/payment');
var refundRouter = require('./routes/refund');
var helloRouter = require('./routes/hello');
var accountRouter = require('./routes/settle_account');
var corpMemberRouter = require('./routes/corp_member');
var memberRouter = require('./routes/member');
var billRouter = require('./routes/bill');
var entryRouter = require('./routes/entry');
var unionRouter = require('./routes/union');
var cashsRouter = require('./routes/cashs');
var batchInputRouter = require('./routes/batchInput');
var walletRouter = require('./routes/wallet');
var merProfileRouter = require('./routes/merProfile');

var app = express();

//设置跨域访问
app.all('*', function(req, res, next) {
  res.header("Access-Control-Allow-Origin", "*");
  res.header("Access-Control-Allow-Headers", "Content-Type,Content-Length, Authorization, Accept,X-Requested-With");
  res.header("Access-Control-Allow-Methods","PUT,POST,GET,DELETE,OPTIONS");
  res.header("X-Powered-By",' 3.2.1')
  if(req.method=="OPTIONS") res.send(200);/*让options请求快速返回*/
  else  next();
});

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'jade');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

app.use('/', indexRouter);
app.use('/api/', helloRouter);
app.use('/api/v1/payment', paymentRouter);
app.use('/api/v1/refund', refundRouter);
app.use('/api/v1/settle_account', accountRouter);
app.use('/api/v1/corp_member', corpMemberRouter);
app.use('/api/v1/member', memberRouter);
app.use('/api/v1/bill', billRouter);
app.use('/api/v1/entry', entryRouter);
app.use('/api/v1/union', unionRouter);
app.use('/api/v1/cashs', cashsRouter);
app.use('/api/v1/batchInput', batchInputRouter);
app.use('/api/v1/wallet', walletRouter);
app.use('/api/v1/merProfile', merProfileRouter);

// catch 404 and forward to error handler
app.use(function(req, res, next) {
  next(createError(404));
});

// error handler
app.use(function(err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render('error');
});

var Adapay = require('./utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('./AdaPay-node-sdk/adapay-sdk/pay/AdaPay')
// 设置基本参数
let config = {}
config.debug = true
config.prod_mode = true

config.connect_timeout = 60000
config.log_file_path = resolve("./logs/")
config.log_console_enable = true

Adapay.set_config(config)
Adapay.set_merchant_path(resolve('./utils/merchantConfig.json'))

// 消息订阅
var Message = require('./utils/sdk/adapay-sdk/adapay-core/Message')
// var Message = require('./AdaPay-node-sdk/adapay-sdk/adapay-core/Message')
var payMsg_1 = new Message(config, resolve('./utils/merchantConfig.json'))

payMsg_1.on('connect', function() {
  console.log('payMsg_1 消息链接成功!')
})

payMsg_1.on('error', function(err) {
  console.log('payMsg_1 mqtt connect error: ' + err.toString())
})

//topic
payMsg_1.on('message', function(topic, message) {
  // message is Buffer
  console.log('payMsg_1 mqtt connect message: ' + message.toString())
})

payMsg_1.on('subscribe', function(error, granted) {
  if (error) {
    console.log('payMsg_1 mqtt subscribe error: ' + granted.toString())
  }
  console.log('payMsg_1 消息订阅成功!')
})

// 设置mqtt需要用到的 client_id 
// var hash_2 = crypto.createHash('md5');
// hash_2.update("Adapay.Config.api_key" + uuid.v1 + "222");
// Adapay.Config.client_id = Adapay.Config.group_id + '@@@' + hash_2.digest('hex');
// // 消息订阅
// var payMsg_2 = new Adapay.Message()

// payMsg_2.on('connect', function() {
//   console.log('payMsg_2 消息链接成功!')
// })

// payMsg_2.on('error', function(err) {
//   console.log('payMsg_2 mqtt connect error: ' + err.toString())
// })

//topic
// payMsg_2.on('message', function(topic, message) {
//   // message is Buffer
//   console.log('payMsg_2 mqtt connect message: ' + message.toString())
// })

// payMsg_2.on('subscribe', function(error, granted) {
//   if (error) {
//     console.log('payMsg_2 mqtt subscribe error: ' + message.toString())
//   }
//   console.log('payMsg_2 消息订阅成功!')
// })

module.exports = app;

// http://192.168.15.97:30050/
// http://192.168.16.89:30050/
// http://192.168.16.90:30050/
