var express = require('express');
var router = express.Router();
var Adapay = require('../utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('../Adapay-node-sdk/adapay-sdk/pay/AdaPay')
var Utils = require('../utils/Utils')
var crypto = require('crypto');
const {resolve} = require('path')

var multipart = require('connect-multiparty');
var multipartMiddleware = multipart();
/**
 *  创建企业用户
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	对应 app 对象的 id,只须放置在请求地址中
    order_no	String(64)	Y	订单号
    member_id	String(64)	Y	商户用户对象 id ，64 位以内，首字母必须是英文、数字或者下划线
    name	String(50)	Y	企业名称
    prov_code	String(4)	Y	省份
    area_code	String(4)	Y	地区
    social_credit_code	String(18)	Y	统一社会信用码
    social_credit_code_expires	String(8)	Y	统一社会信用证有效期
    business_scope	String(200)	N	经营范围
    legal_person	String(20)	Y	法人姓名
    legal_cert_id	String(20)	Y	法人身份证号码
    legal_cert_id_expires	String(8)	N	法人身份证有效期
    legal_mp	String(11)	Y	法人手机号
    address	String(256)	Y	企业地址
    zip_code	String(6)	N	邮编
    telphone	String(30)	N	企业电话
    email	String(40)	N	企业邮箱
    attach_file	File	Y	上传附件，传入的中文文件名称为 UTF-8 字符集 URLEncode 编码后的字符串。内容须包含三证合一证件照、法人身份证正面照、法人身份证反面照、开户银行许可证照。 压缩 zip包后上传，最大限制为 4 M。
    bank_code	String(8)	N	银行代码，如果需要自动开结算账户，本字段必填
    bank_acct_type	String(1)	N	银行账户类型：1-对公；2-对私，如果需要自动开结算账户，本字段必填
    card_no	String(40)	N	银行卡号，如果需要自动开结算账户，本字段必填
    card_name	String(16)	N	银行卡开户姓名，如果需要自动开结算账户，本字段必填
 */
router.post('/create', multipartMiddleware, async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, name, prov_code, area_code, social_credit_code, social_credit_code_expires, business_scope, legal_person, legal_cert_id, legal_cert_id_expires, legal_mp, address, zip_code, telphone, email, bank_code, bank_acct_type, card_no, card_name, merchantNO} = req.body
        
        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        var md5 = crypto.createHash('md5');
        var order_no = (new Date()).valueOf()
        var member_id = md5.update(`${order_no}`).digest('hex');

        let obj = Utils.checkObject({
            app_id, order_no, member_id, name, prov_code, area_code, social_credit_code, social_credit_code_expires, business_scope, legal_person, legal_cert_id, legal_cert_id_expires, legal_mp, address, zip_code, telphone, email, bank_code, bank_acct_type, card_no, card_name
        })

        // 文件处理
        let {attach_file} = req.files

        let result = await Adapay.CorpMember.create(obj, attach_file.path)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  查询企业用户
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	对应 app 对象的 id
    member_id	String(64)	Y	商户用户对象 id ，64 位以内，首字母必须是英文、数字或者下划线
 */
router.post('/query', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, merchantNO} = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id
        })

        let result = await Adapay.CorpMember.query(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

module.exports = router;