var express = require('express');
var router = express.Router();
var Merchant = require('../utils/sdk/adapay-sdk/merchant/Merchant')
const {resolve} = require('path')

 // 设置基本参数
 let config = {}
 config.debug = true
 config.prod_mode = true
 
 config.connect_timeout = 60000
 config.log_file_path = resolve("./logs/")
 config.log_console_enable = true
 Merchant.set_config(config)
 Merchant.set_merchant_path(resolve('../utils/merchantConfig.json'))

/**
 *  进件接口
 * @param {Object} kwargs 
 * 参数说明
    请求ID	request_id	变长32位String	Y	 
    注册手机号	usr_phone	变长11为String	Y	不能重复
    联系人姓名	cont_name	变长16位String	Y	 
    联系人手机号码	cont_phone	变长11位String	Y	成功进件后重复测试需修改该字段
    电子邮箱	customer_email	变长60位String	Y	成功进件后重复测试需修改该字段
    商户名	mer_name	变长32位String	Y	 
    商户名简称	mer_short_name	变长10位String	Y	 
    营业执照编码	license_code	变长22位String	N	企业时必填，如三证合一则传三证合一码
    注册地址	reg_addr	变长60位String	N	企业时必填(多次进件地址重复会导致入驻失败)
    经营地址	cust_addr	变长60位String	N	企业时必填(多次进件地址重复会导致入驻失败)
    商户电话	cust_tel	变长20位String	Y	 
    商户证件有效期开始时间	mer_start_valid_date	定长8位String	Y	YYYYMMDD
    商户有效日期（至）	mer_valid_date	定长8位String	Y	YYYYMMDD
    法人/负责人 姓名	legal_name	变长16位String	Y	 
    证件类型	legal_type	定长1位String	Y	0-身份证 1-其他
    证件号码	legal_idno	变长25位String	Y	 
    法人手机号	legal_mp	变长32位String	Y	 
    法人身份证有效期开始时间	legal_start_cert_id_expires	定长8位String	Y	YYYYMMDD
    法人身份证有效期（至）	legal_id_expires	定长8位String	Y	YYYYMMDD
    结算银行卡号	card_id_mask	变长64位String	Y	 
    结算银行卡所属银行code	bank_code	定长8位String	Y	
    见api文档

    https://docs.adapay.tech/api/appendix.html#bank-code

    结算银行卡开户姓名	card_name	变长64位String	Y	 
    结算银行账户类型	bank_acct_type	定长1位String	Y	1:对公2:对私
    结算银行卡省份	prov_code	变长4位String	Y	 
    结算银行卡地区	area_code	变长4位String	Y	 
    商户 rsa 公钥	rsa_public_key	变长1024位String	Y	 
    费率列表	fee_rate_list	变长的String	N	
    费率列表，json字符串，根据所需支付渠道配置对应费率

    rate_channel为支付渠道，fee_rate为费率值，费率值为不超过10位的小数，支付渠道枚举如下：

    wx_pub_online:微信公众号支付（线上）

    wx_pub_offline:微信公众号支付（线下）

    wx_lite_online:微信小程序支付（线上）

    wx_lite_offline:微信小程序支付（线下）

    wx_scan:微信扫码支付（被扫-线下）

    alipay_qr_online:支付宝扫码支付（主扫-线上）

    alipay_qr_offline:支付宝扫码支付（主扫-线下）

    alipay_scan:支付宝扫码支付（被扫-线下）

    alipay_lite_online:支付宝小程序支付（线上）

    alipay_lite_offline:支付宝小程序支付（线下）

    alipay_call:支付宝唤起支付（线上）

    union_qr_under:银联云闪付扫码支付交易金额≤1000元（线下）

    union_qr_beyond:银联云闪付扫码支付交易金额>1000元（线下）

    union:银联云闪付控件支付（线上）

    参数具体示例如下：

    [{
            "rate_channel": "wx_pub_online",
            "fee_rate": "0.003"
        }, {
            "rate_channel": "wx_pub_offline",
            "fee_rate": "0.003"
        }, {
            "rate_channel": "wx_lite_online",
            "fee_rate": "0.004"
        }, {
            "rate_channel": "wx_lite_offline",
            "fee_rate": "0.004"
        }, {
            "rate_channel": "wx_scan",
            "fee_rate": "0.0035"
        }, {
            "rate_channel": "alipay_qr_online",
            "fee_rate": "0.0038"
        }, {
            "rate_channel": "alipay_qr_offline",
            "fee_rate": "0.0068"
        }, {
            "rate_channel": "alipay_scan",
            "fee_rate": "0.0038"
        }, {
            "rate_channel": "alipay_lite_online",
            "fee_rate": "0.0038"
        }, {
            "rate_channel": "alipay_lite_offline",
            "fee_rate": "0.0068"
        }, {
            "rate_channel": "alipay_call",
            "fee_rate": "0.0038"
        }, {
            "rate_channel": "union_qr_under",
            "fee_rate": "0.004"
        }, {
            "rate_channel": "union_qr_beyond",
            "fee_rate": "0.007"
        }, {
            "rate_channel": "union",
            "fee_rate": "0.0068"
        }
    ]
 */
router.post('/batchEntrys', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, merchantNO,
            request_id, usr_phone, cont_name, cont_phone, customer_email, mer_name, mer_short_name,
            license_code, reg_addr, cust_addr, cust_tel, mer_start_valid_date, mer_valid_date, 
            legal_name, legal_type, legal_idno, legal_mp, legal_start_cert_id_expires, legal_id_expires,
            card_id_mask, bank_code, card_name, bank_acct_type, prov_code, area_code, rsa_public_key,
            fee_rate_list
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.Entry.batchEntrys({
            request_id, usr_phone, cont_name, cont_phone, customer_email, mer_name, mer_short_name,
            license_code, reg_addr, cust_addr, cust_tel, mer_start_valid_date, mer_valid_date, 
            legal_name, legal_type, legal_idno, legal_mp, legal_start_cert_id_expires, legal_id_expires,
            card_id_mask, bank_code, card_name, bank_acct_type, prov_code, area_code, rsa_public_key,
            fee_rate_list
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  进件结果查询
 * @param {Object} kwargs 
 * 参数说明
    请求ID	request_id	变长32位String	Y	进件接口使用的request_id
 */
router.post('/queryEntry', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, merchantNO,
            request_id,
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.Entry.queryEntry({
            request_id
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  创建应用
 * @param {Object} kwargs 
 * 参数说明
    商户apikey	sub_api_key	变长64位String	Y	 
    应用名称	app_name	变长200为String	Y	不能重复
 */
router.post('/createApplication', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO,
            sub_api_key, app_name
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.Entry.createApplication({
            sub_api_key, app_name
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  应用查询
 * @param {Object} kwargs 
 * 参数说明
    商户apikey	sub_api_key	变长64位String	Y
 */
router.post('/queryApplication', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO,
            sub_api_key
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.Entry.queryApplication({
            sub_api_key
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

module.exports = router;
