var express = require('express');
var router = express.Router();
var Adapay = require('../utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('../Adapay-node-sdk/adapay-sdk/pay/AdaPay')
var crypto = require('crypto');
var Utils = require('../utils/Utils')
const {resolve} = require('path')

/**
 *  创建用户对象
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	商户应用id
    member_id	String(64)	Y	商户用户id，64 位以内，首字母必须是英文、数字或者下划线
    location	String(128)	N	用户地址
    email	String(64)	N	用户邮箱
    gender	String(16)	N	MALE：男，FEMALE：女，为空时表示未填写
    tel_no	String(11)	N	用户手机号
    nickname	String(16)	N	用户昵称
 */
router.post('/create', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, location, email, gender, tel_no, nickname, merchantNO } = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        var md5 = crypto.createHash('md5');
        var date = (new Date()).valueOf()
        var member_id = md5.update(`${date}`).digest('hex');

        let obj = Utils.checkObject({
            app_id, member_id, location, email, gender, tel_no, nickname
        })

        let result = await Adapay.Member.create(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  查询用户对象信息
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	商户应用id，放在请求url地址中
    member_id	String(64)	Y	商户用户id，64 位以内，首字母必须是英文、数字或者下划线
 */
router.post('/query', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, merchantNO} = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id
        })

        let result = await Adapay.Member.query(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  更新用户对象
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	商户应用id
    member_id	String(64)	Y	商户用户id，64 位以内，首字母必须是英文、数字或者下划线
    location	String(128)	N	用户地址
    email	String(64)	N	用户邮箱
    gender	String(16)	N	MALE：男，FEMALE：女，为空时表示未填写
    tel_no	String(11)	N	用户手机号
    disabled	String	N	是否禁用该用户，Y：是，N：否
    nickname	String(16)	N	用户昵称
 */
router.post('/update', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, location, email, gender, tel_no, nickname, disabled, merchantNO } = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, location, email, gender, tel_no, nickname, disabled
        })
        
        let result = await Adapay.Member.update(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  查询用户对象列表
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	商户应用id
    page_index	int	N	当前页码，取值范围1~300000，默认值为1
    page_size	int	N	页面容量，取值范围1~20，默认值为10
    created_gte	String	N	查询大于等于创建时间
    created_lte	String	N	查询小于等于创建时间；若不为空时，created_gte字段值不能为空且小于created_lte时间
 */
router.post('/list', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, page_index, page_size, created_gte, created_lte, merchantNO } = req.body
        
        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, page_index, page_size, created_gte, created_lte
        })

        let result = await Adapay.Member.list(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

module.exports = router;