var express = require('express');
var router = express.Router();
var Adapay = require('../utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('../Adapay-node-sdk/adapay-sdk/pay/AdaPay')
var Utils = require('../utils/Utils')
const {resolve} = require('path')

// 创建订单的 Payment 对象
router.post('/create', async function (req, res, next) {
    try {
        let { env, prod_mode, currency, pay_amt, app_id, pay_channel, goods_title, goods_desc, description, time_expire, device_info, expend, allocate_users, notify_url, merchantNO } = req.body

        // allocate_users  用户分账使用 分账对象信息列表，json 形式
        // user_id	String(64)	Y	分账用户User对象的id
        // amount	String(14)	Y	分账金额
        // fee_flag	String(1)	N	是否手续费承担方，N-否，Y-是，手续费承担方有且只能有一个

        // {"app_id":"app_7d87c043-aae3-4357-9b2c-269349a980d6","created_time":"1571733127","expend":{"pay_info":"https://qr.alipay.com/bax04287u87me4e7uqfu2026"},"id":"002112019102216320710032635256019734528","object":"payment","order_no":"20190101120001571733126970","pay_amt":"1.00","pay_channel":"alipay","prod_mode":"true","query_url":"https://api.adapay.tech/v1/expire/payments/1/2aefb2a080b5974f59bdee0d7bbd2913","status":"succeeded"}

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let order_no = '2019010112000' + (new Date().valueOf())

        let obj = Utils.checkObject({
            currency: currency,
            order_no: order_no,
            app_id: app_id,
            pay_channel: pay_channel,
            pay_amt: pay_amt,
            goods_title: goods_title,
            goods_desc: goods_desc,
            description: description,
            time_expire: time_expire,
            device_info: device_info,
            expend: expend,
            allocate_users: allocate_users,
            notify_url: notify_url
        })
        
        let result = await Adapay.Payment.create(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 查询订单支付结果
router.post('/query', async function (req, res, next) {
    try {
        let { env, prod_mode, payment_id, merchantNO } = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Adapay.Payment.query({
            payment_id
        })

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 关单
router.post('/close', async function (req, res, next) {
    try {
        let { env, prod_mode, payment_id, notify_url, merchantNO } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            payment_id: payment_id,
            notify_url: notify_url
        })

        let result = await Adapay.Payment.close(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})


// 支付确认
router.post('/confirm', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, payment_id, order_no, confirm_amt, description, div_members } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            payment_id, order_no, confirm_amt, description, div_members
        })

        let result = await Adapay.Payment.confirm(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 查询支付确认对象
router.post('/query_confirm', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, payment_confirm_id } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            payment_confirm_id
        })

        let result = await Adapay.Payment.queryConfirm(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 查询支付确认对象列表
router.post('/query_confirm_list', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, payment_id, page_index, page_size, created_gte, created_lte } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, payment_id, page_index, page_size, created_gte, created_lte
        })

        let result = await Adapay.Payment.queryConfirmList(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 创建支付撤销对象
router.post('/reverse', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, payment_id, order_no, notify_url, reverse_amt, reason, expand, device_info } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, payment_id, order_no, notify_url, reverse_amt, reason, expand, device_info
        })

        let result = await Adapay.Payment.reverse(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 查询支付撤销对象
router.post('/query_reverse', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, reverse_id } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            reverse_id
        })

        let result = await Adapay.Payment.queryReverse(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

// 查询支付撤销对象列表
router.post('/query_reverse_list', async function (req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, payment_id, page_index, page_size, created_gte, created_lte } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, payment_id, page_index, page_size, created_gte, created_lte
        })

        let result = await Adapay.Payment.queryReverseList(obj)

        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

module.exports = router;