var express = require('express');
var router = express.Router();
var Adapay = require('../utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('../Adapay-node-sdk/adapay-sdk/pay/AdaPay')
var Utils = require('../utils/Utils')
const {resolve} = require('path')

/**
 *  创建结算账户
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	应用id
    member_id	String(64)	Y	用户ID，64 位以内，首字母必须是英文、数字或者下划线
    channel	String	Y	目前仅支持：bank_account（银行卡）
    account_info	recipient	Y	结算账号信息
    
    account_info字段说明：
    参数	类型	非空	说明
    card_id	String(64)	Y	银行卡号
    card_name	String(16)	Y	银行卡开户姓名
    cert_id	String(30)	Y	身份证号
    cert_type	String(2)	N	默认：00－身份证
    tel_no	String(11)	Y	手机号
    bank_code	String(8)	Y	详见开户银行编码附录
    bank_name	String(64)	N	开户银行名称
    bank_acct_type	String(1)	Y	银行账户类型：1-对公；2-对私
    prov_code	String(4)	Y	省份
    area_code	String(4)	Y	地区
 */
router.post('/create', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, channel, account_info, merchantNO} = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, channel, account_info
        })

        let result = await Adapay.Account.create(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  查询结算账户
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	应用ID
    member_id	String(64)	Y	用户ID，64 位以内，首字母必须是英文、数字或者下划线
    settle_account_id	String	Y	由Adapay生成的结算账户对象id，url地址中获取
 */
router.post('/query', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, settle_account_id, merchantNO} = req.body

        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, settle_account_id
        })

        let result = await Adapay.Account.query(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  删除结算账户
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	url地址中获取
    member_id	String(64)	Y	用户ID，64 位以内，首字母必须是英文、数字或者下划线
    settle_account_id	String	Y	由Adapay生成的结算账户对象id
 */
router.post('/delete', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, settle_account_id, merchantNO} = req.body
        
        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, settle_account_id
        })

        let result = await Adapay.Account.deleteAccount(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  查询结算明细列表
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	应用ID
    member_id	String(64)	Y	用户ID，64 位以内，必须是英文、数字或者下划线，若查询商户本身时，传入值0
    settle_account_id	String(64)	N	由Adapay生成的结算账户对象id，若查询商户本身时，可以为空
    begin_date	String(8)	Y	结算起始日期，格式为 yyyyMMdd
    end_date	String(8)	Y	结算结束日期，格式为 yyyyMMdd
 */
router.post('/settle_details', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, settle_account_id, begin_date, end_date, merchantNO} = req.body
        
        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, settle_account_id, begin_date, end_date
        })

        let result = await Adapay.Account.querySettleDetail(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

/**
 *  修改结算配置
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	应用id
    member_id	String(64)	Y	用户id
    settle_account_id	String(64)	Y	Adapay系统返回的结算账户id
    min_amt	String(16)	N	
    结算起始金额 ( 0.00格式，整数部分最长13位，小数部分最长2位)

    min_amt， remained_amt，channel_remark至少有一个不为空 

    remained_amt	String(16)	N	结算留存金额 ( 0.00格式，整数部分最长13位，小数部分最长2位)
    channel_remark	String(200)	N	结算信息摘要，银行出款时摘要信息
 */
router.post('/modify', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, member_id, settle_account_id, min_am, remained_amt, channel_remark} = req.body
        
        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, settle_account_id, min_am, remained_amt, channel_remark
        })

        let result = await Adapay.Account.modify(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

/**
 *  查询账户余额对象
 * @param {Object} kwargs 
 * 参数说明
    app_id	String(64)	Y	商户的应用 id
    member_id	String(64)	Y	用户id，64 位以内，必须是英文、数字或者下划线
    settle_account_id	String(64)	N	由Adapay生成的结算账户对象id，查询用户余额时不能为空
 */
router.post('/query_balance', async function(req, res, next) {
    try {
        let { 
            env, prod_mode, merchantNO, app_id, member_id, settle_account_id
        } = req.body
        
        Adapay.Config.prod_mode = prod_mode

        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let obj = Utils.checkObject({
            app_id, member_id, settle_account_id
        })

        let result = await Adapay.Account.queryBalance(obj)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
})

module.exports = router;