var express = require('express');
var router = express.Router();
var Adapay = require('../utils/sdk/adapay-sdk/pay/AdaPay')
// var Adapay = require('../Adapay-node-sdk/adapay-sdk/pay/AdaPay')
const {resolve} = require('path')

/**
 *  用户登录
 * 
 *  商户申请用户登录临时token
 * @param {Object} kwargs 
 * 参数说明
 *  app_id	String(64)	Y	应用id
    member_id	String(64)	Y	用户ID，64 位以内，必须是英文、数字或者下划线；若是商户本身，请传入0
    ip	String(64)	Y	用户真实IP，否则无法登录

 */
router.post('/walletLogin', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, member_id, ip, merchantNO } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Adapay.Wallet.walletLogin({
            app_id, member_id, ip
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

/**
 *  钱包支付接口
 * 
 *  关于支付，Adapay 系统内数据是通过 Payment对象 的形式进行流转，所有的支付相关信息都会存储在这个对象中，您可以通过 Adapay 开放的方法创建一个新的 Payment对象，也可以通过 Payment对象 的唯一标识 id 来查询一个已经存在的 Payment对象 状态。只允许商户交易,只允许同一个代理商下交易（多层也可以）
    创建支付对象仅支持实时分账，但需要先创建用户对象并创建结算账户对象，或创建企业用户对象后，才能使用分账功能。
    使用 Adapay 前端 SDK 进行支付时，也会用到 Payment对象，服务端在传 Payment对象 到客户端进行支付前，请先使用序列化方式将对象转换成 JSON 字符串。
 * @param {Object} kwargs 
 * 参数说明
 *  order_no	String(64)	Y	订单号，只能是英文、数字或者下划线的组合，保证在商户应用id下唯一
    app_id	String(64)	Y	商户的应用 id
    pay_amt	String(14)	Y	订单总金额（必须大于0），人民币为元，保留两位小数点，如0.10、100.05等
    currency	String(3)	Y	3 位 ISO 货币代码，小写字母，人民币为 cny
    description	String(128)	N	订单附加说明
    div_members	DivMembers	N	分账对象信息列表，可用于用户分账，若无需分账，该参数为空
    goods_title	String(64)	Y	商品标题
    goods_desc	String(127)	Y	商品描述信息
    callback_url	String(250)	N	支付成功后跳转地址
    notify_url	String(250)	N	异步通知地址，默认使用轻量、简单 MQTT 通知（强烈建议使用），url为http/https 路径，服务器 POST 回调，请不要地址上带有参数。

    div_members 字段说明： 
    名称	类型	必填	描述
    member_id	String(64)	Y	分账用户 Member 对象的id
    amount	String(14)	Y	分账金额
 */
router.post('/pay', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, merchantNO,
            order_no, pay_amt, currency, description, div_members, goods_title, 
            goods_desc, callback_url, notify_url
        } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Adapay.Wallet.pay({
            app_id,
            order_no, pay_amt, currency, description, div_members, goods_title, 
            goods_desc, callback_url, notify_url
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  创建收银台对象
 * 
 *  通过该接口，实现对商户钱包收银台支付功能，下单成功返回支付跳转地址
 * @param {Object} kwargs 
 * 参数说明
 *  
 */
router.post('/createCheckOut', async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, merchantNO,
            order_no, member_id, pay_amt, currency, goods_title, goods_desc, 
            callback_url
        } = req.body

        Adapay.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Adapay.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Adapay.Config.config_dirname = resolve('./utils/config_test')
            Adapay.Config.base_url = "https://api-test.adapay.tech"
        }
        // Adapay.set_merchant_path(configFilePath)
        Adapay.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Adapay.Wallet.createCheckOut({
            app_id, order_no, member_id, pay_amt, currency, goods_title, goods_desc, 
            callback_url
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


module.exports = router;
